---
title: MySqlBatch
---

# MySqlBatch class

[`MySqlBatch`](../MySqlBatchType/) implements the new [ADO.NET batching API](https://github.com/dotnet/runtime/issues/28633). It is currently experimental and may change in the future.

When using MariaDB (10.2 or later), the commands will be sent in a single batch, reducing network round-trip time. With other MySQL Servers, this may be no more efficient than executing the commands individually.

Example usage:

```csharp
using var connection = new MySqlConnection("...connection string...");
await connection.OpenAsync();

using var batch = new MySqlBatch(connection)
{
	BatchCommands =
	{
		new MySqlBatchCommand("INSERT INTO departments(name) VALUES(@name);")
		{
			Parameters =
			{
				new MySqlParameter("@name", "Sales"),
			},
		},
		new MySqlBatchCommand("SET @dept_id = last_insert_id()"),
		new MySqlBatchCommand("INSERT INTO employees(name, department_id) VALUES(@name, @dept_id);")
		{
			Parameters =
			{
				new MySqlParameter("@name", "Jim Halpert"),
			},
		},
	 	new MySqlBatchCommand("INSERT INTO employees(name, department_id) VALUES(@name, @dept_id);")
		{
			Parameters =
			{
				new MySqlParameter("@name", "Dwight Schrute"),
			},
		},
	},
 };
 await batch.ExecuteNonQueryAsync();
```

```csharp
public sealed class MySqlBatch : DbBatch
```

## Public Members

| name | description |
| --- | --- |
| [MySqlBatch](../MySqlBatch/MySqlBatch/)() | Initializes a new [`MySqlBatch`](../MySqlBatchType/) object. The [`Connection`](../MySqlBatch/Connection/) property must be set before this object can be used. |
| [MySqlBatch](../MySqlBatch/MySqlBatch/)(…) | Initializes a new [`MySqlBatch`](../MySqlBatchType/) object, setting the [`Connection`](../MySqlBatch/Connection/) and [`Transaction`](../MySqlBatch/Transaction/) if specified. |
| [BatchCommands](../MySqlBatch/BatchCommands/) { get; } | The collection of commands that will be executed in the batch. |
| [Connection](../MySqlBatch/Connection/) { get; set; } |  |
| override [Timeout](../MySqlBatch/Timeout/) { get; set; } |  |
| [Transaction](../MySqlBatch/Transaction/) { get; set; } |  |
| override [Cancel](../MySqlBatch/Cancel/)() |  |
| override [Dispose](../MySqlBatch/Dispose/)() |  |
| override [ExecuteNonQuery](../MySqlBatch/ExecuteNonQuery/)() |  |
| override [ExecuteNonQueryAsync](../MySqlBatch/ExecuteNonQueryAsync/)(…) |  |
| [ExecuteReader](../MySqlBatch/ExecuteReader/)(…) | Executes all the commands in the batch, returning a [`MySqlDataReader`](../MySqlDataReaderType/) that can iterate over the result sets. If multiple resultsets are returned, use [`NextResult`](../MySqlDataReader/NextResult/) to access them. |
| [ExecuteReaderAsync](../MySqlBatch/ExecuteReaderAsync/)(…) | Executes all the commands in the batch, returning a [`MySqlDataReader`](../MySqlDataReaderType/) that can iterate over the result sets. If multiple resultsets are returned, use [`NextResultAsync`](../MySqlDataReader/NextResultAsync/) to access them. |
| override [ExecuteScalar](../MySqlBatch/ExecuteScalar/)() |  |
| override [ExecuteScalarAsync](../MySqlBatch/ExecuteScalarAsync/)(…) |  |
| override [Prepare](../MySqlBatch/Prepare/)() |  |
| override [PrepareAsync](../MySqlBatch/PrepareAsync/)(…) |  |

## Protected Members

| name | description |
| --- | --- |
| override [DbBatchCommands](../MySqlBatch/DbBatchCommands/) { get; } |  |
| override [DbConnection](../MySqlBatch/DbConnection/) { get; set; } |  |
| override [DbTransaction](../MySqlBatch/DbTransaction/) { get; set; } |  |
| override [CreateDbBatchCommand](../MySqlBatch/CreateDbBatchCommand/)() |  |
| override [ExecuteDbDataReader](../MySqlBatch/ExecuteDbDataReader/)(…) |  |
| override [ExecuteDbDataReaderAsync](../MySqlBatch/ExecuteDbDataReaderAsync/)(…) |  |

## Remarks

The proposed ADO.NET API that [`MySqlBatch`](../MySqlBatchType/) is based on is not finalized. This API is experimental and may change in the future.

## See Also

* namespace [MySqlConnector](../../MySqlConnectorNamespace/)
* assembly [MySqlConnector](../../MySqlConnectorAssembly/)

<!-- DO NOT EDIT: generated by xmldocmd for MySqlConnector.dll -->
